//
// "$Id: rounded_box.cxx 9560 2012-05-30 21:04:33Z matt $"
//
// Rounded box drawing routines for the Fast Light Tool Kit (FLTK).
//
// Copyright 1998-2010 by Bill Spitzak and others.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//
// Please report all bugs and problems on the following page:
//
//     http://www.fltk.org/str.php
//

#include <fltk3/run.h>
#include <fltk3/draw.h>

#define RN	5
#define RS	15
#define BW	3

static double offset[RN] = { 0.0, 0.07612, 0.29289, 0.61732, 1.0};

static void rbox(int fill, int x, int y, int w, int h) {
  int i;
  int rsx ,rsy, rs;
  rsx = w*2/5; rsy = h*2/5;
  if (rsx > rsy) rs = rsy; else  rs = rsx;
  if (rs > RS) rs = RS;
  rsx = rs; rsy = rs;

  if (fill) fltk3::begin_polygon(); else fltk3::begin_loop();
  for (i=0; i<RN; i++)
    fltk3::vertex(x + offset[RN-i-1]*rsx, y + offset[i] * rsy);
  for (i=0; i<RN; i++)
    fltk3::vertex(x + offset[i]*rsx, y + h-1 - offset[RN-i-1] * rsy);
  for (i=0; i<RN; i++)
    fltk3::vertex(x + w-1 - offset[RN-i-1]*rsx, y + h-1 - offset[i] * rsy);
  for (i=0; i<RN; i++)
    fltk3::vertex(x + w-1 - offset[i]*rsx, y + offset[RN-i-1] * rsy);
  if (fill) fltk3::end_polygon(); else fltk3::end_loop();
}

void fl_rflat_box(int x, int y, int w, int h, fltk3::Color c, fltk3::Box*) {
  fltk3::color(c); rbox(1, x, y, w, h); rbox(0, x, y, w, h);
}

void fl_rounded_frame(int x, int y, int w, int h, fltk3::Color c, fltk3::Box*) {
  fltk3::color(c); rbox(0, x, y, w, h);
}

void fl_rounded_box(int x, int y, int w, int h, fltk3::Color c, fltk3::Box*) {
  fltk3::color(c); rbox(1, x, y, w, h);
  fltk3::color(fltk3::BLACK); rbox(0, x, y, w, h);
}

void fl_rshadow_box(int x, int y, int w, int h, fltk3::Color c, fltk3::Box* t) {
  // draw shadow:
  fltk3::color(fltk3::DARK3);
  rbox(1, x+BW, y+BW, w, h);
  rbox(0, x+BW, y+BW, w, h);
  // draw the box:
  fl_rounded_box(x, y, w, h, c, t);
}

//
// End of "$Id: rounded_box.cxx 9560 2012-05-30 21:04:33Z matt $".
//
